""" Contains individual GUI components """
from .entry_visualization import entry_table, task_chart
from .menu_settings import settings_menu
from .timer import number, timer_display
